cosmpy.protos.ibc.applications package — cosmpy documentation

# cosmpy.protos.ibc.applications package

## Subpackages

- cosmpy.protos.ibc.applications.transfer package
  - Subpackages
    - cosmpy.protos.ibc.applications.transfer.v1 package
      - Submodules
      - cosmpy.protos.ibc.applications.transfer.v1.genesis_pb2 module
      - cosmpy.protos.ibc.applications.transfer.v1.genesis_pb2_grpc module
      - cosmpy.protos.ibc.applications.transfer.v1.query_pb2 module
      - cosmpy.protos.ibc.applications.transfer.v1.query_pb2_grpc module
      - cosmpy.protos.ibc.applications.transfer.v1.transfer_pb2 module
      - cosmpy.protos.ibc.applications.transfer.v1.transfer_pb2_grpc module
      - cosmpy.protos.ibc.applications.transfer.v1.tx_pb2 module
      - cosmpy.protos.ibc.applications.transfer.v1.tx_pb2_grpc module
      - Module contents
  - Module contents

## Module contents